<?php
/* Copyright start
  Copyright (C) 2008 - 2024 Fortinet Inc.
  All rights reserved.
  FORTINET CONFIDENTIAL & FORTINET PROPRIETARY SOURCE CODE
  Copyright end */

namespace App\Service\ConfigExportImport;

use Psr\Log\LoggerInterface;
use App\Constants\AppConstants;
use App\Constants\ErrorConstants;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Serializer\Normalizer\NormalizerInterface;
use Symfony\Component\Security\Core\Authentication\Token\Storage\TokenStorageInterface;

/**
 * Class ModuleConfig
 * @package App\Service\ConfigExportImport
 */
class ExternalTemplateConfig extends PortingConfig
{

    public const EXTERNAL_TEMPLATE_DIR = 'externalTemplates/';

    public function __construct(
        EntityManagerInterface $entityManager,
        NormalizerInterface $normalizer,
        TokenStorageInterface $tokenStorage,
        ContainerInterface $container,
        protected LoggerInterface $logger
    ) {
        parent::__construct(
            $entityManager,
            $normalizer,
            $tokenStorage,
            $container,
            $logger
        );
    }

    /**
     * @param array $allData
     * @param string $key
     * @return array
     */
    public function getImportOptions(array $allData, string $key, $tokenType)
    {
        return ['include' => true];
    }

    private function loadViewTemplates(string $key, string $tmpDirectory)
    {
        $viewTemplates = [];
        if ($key == 'externalTemplates') {
            $viewTemplatesPath = $tmpDirectory . self::EXTERNAL_TEMPLATE_DIR;
            $viewTemplates = $this->collectViewTemplates($viewTemplatesPath);
        }
        return $viewTemplates;
    }

    private function collectViewTemplates($folderPath)
    {
        $folders = [];
        if (file_exists($folderPath)) {
            $folders = scandir($folderPath);
        }
        $data = [];
        foreach ($folders as $folder) {
            $viewPaths = [
                $folderPath . $folder . '/detail-layout.json',
                $folderPath . $folder . '/list-layout.json',
                $folderPath . $folder . '/form-layout.json',
                $folderPath . $folder . '/settings.json'
            ];
            foreach ($viewPaths as $viewPath) {
                if (file_exists($viewPath)) {
                    $fileData = file_get_contents($viewPath);
                    $jsonData = json_decode($fileData, true);
                    $data[] = $jsonData;
                }
            }
        }
        return $data;
    }

    private function importViewTemplates($key, $tmpDirectory, $tokenType)
    {
        try {
            // Importing generic view templates
            $viewTemplates = $this->loadViewTemplates($key, $tmpDirectory);
            if ($viewTemplates) {
                $fullURI = sprintf('%s/api/3/bulkupsert/system_view_templates', $this->container->getParameter(AppConstants::CRUDHUB_PARAMETER_KEY));
                $body = [
                    "__unique" => ['uuid'],
                    "__replace" => true,
                    "__data" => $viewTemplates
                ];
                $this->sendRequest($fullURI, 'post', $body, $tokenType);
            }
        } catch (\Exception $ex) {
            $this->logger->error(ErrorConstants::FSR_CH_0000026);
            $this->logger->error($ex);
        }
    }

    /**
     * Imports the config data using the specified options
     *
     * @param array $data
     * @param array $options
     * @return mixed
     */
    public function import(array $data, array $options, $tokenType, $importedBy = [])
    {
        return true;
    }

    /**
     * Exports the config using the specified options
     *
     * @param array $options list of MMDs to export
     * @return array
     */
    public function export(array $options, $tokenType = 'JWT') {}

    /**
     * Exports the config to a tmp file using the specified options
     *
     * @param array $options
     * @param string $type
     * @param string $tokenType
     * @return void
     */
    public function exportFile(array $options, $type, $tmpDirectory, $tokenType = 'JWT')
    {
        return [];
    }

    /**
     * Generates import options from the tmp folder
     *
     * @param string $key
     * @param string $tmpDirectory
     * @param string $tokenType
     * @return array
     */
    public function getImportOptionsFromFile(string $key, string $tmpDirectory, $tokenType)
    {
        return $this->getImportOptions([$key => true], $key, $tokenType);
    }

    /**
     * Imports from the tmp folder
     *
     * @param array $options
     * @param string $key
     * @param string $tmpDirectory
     * @param [type] $tokenType
     * @return void
     */
    public function importFromFile(array $options, string $key, string $tmpDirectory, $tokenType, $importedBy = [])
    {
        $this->importViewTemplates($key, $tmpDirectory, $tokenType);
        return true;
    }

    public function generateExportOptions(array $options, $tokenType = 'JWT')
    {
        return [];
    }

    public function generateInfoContent(array $options)
    {
        return [];
    }
}
