<?php
/* Copyright start
  Copyright (C) 2008 - 2024 Fortinet Inc.
  All rights reserved.
  FORTINET CONFIDENTIAL & FORTINET PROPRIETARY SOURCE CODE
  Copyright end */

namespace App\Service\ConfigExportImport;

use Psr\Log\LoggerInterface;
use App\Constants\AppConstants;
use App\Constants\ErrorConstants;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\Serializer\Normalizer\NormalizerInterface;
use Symfony\Component\Security\Core\Authentication\Token\Storage\TokenStorageInterface;

/**
 * Class ModuleConfig
 * @package App\Service\ConfigExportImport
 */
class FixtureConfig extends PortingConfig
{
    public function __construct(
        EntityManagerInterface $entityManager,
        NormalizerInterface $normalizer,
        TokenStorageInterface $tokenStorage,
        ContainerInterface $container,
        protected LoggerInterface $logger
    ) {
        parent::__construct($entityManager, $normalizer, $tokenStorage, $container, $logger);
    }

    /**
     * @param array $allData
     * @param string $key
     * @return array
     */
    public function getImportOptions(array $allData, string $key, $tokenType)
    {
        return ['include' => true];
    }

    /**
     * Imports the config data using the specified options
     *
     * @param array $data
     * @param array $options
     * @return mixed
     */
    public function import(array $data, array $options, $tokenType, $importedBy = [])
    {
        try{
            if ($data) {
                foreach ($data as $fixtureFileName => $fixtureFileData) {
                    file_put_contents(AppConstants::STATIC_FILE_DIR . $fixtureFileName . '.json', json_encode($fixtureFileData, JSON_PRETTY_PRINT | JSON_UNESCAPED_UNICODE));
                }
            }
            return true;
        } catch(\Exception $ex){
            $this->logger->error($ex->getMessage());
            throw new \Exception(sprintf(ErrorConstants::FSR_CH_0000025));
        }
    }

    /**
     * Exports the config using the specified options
     *
     * @param array $options list of MMDs to export
     * @return array
     */
    public function export(array $options, $tokenType = 'JWT') {}

    /**
     * Exports the config to a tmp file using the specified options
     *
     * @param array $options
     * @param string $type
     * @param string $tokenType
     * @return void
     */
    public function exportFile(array $options, $type, $tmpDirectory, $tokenType = 'JWT')
    {
        return [];
    }

    /**
     * Generates import options from the tmp folder
     *
     * @param string $key
     * @param string $tmpDirectory
     * @param string $tokenType
     * @return array
     */
    public function getImportOptionsFromFile(string $key, string $tmpDirectory, $tokenType)
    {
        $data = $this->loadDataFromDirectory($key, $tmpDirectory);
        return $this->getImportOptions([$key => $data], $key, $tokenType);
    }

    /**
     * Imports from the tmp folder
     *
     * @param array $options
     * @param string $key
     * @param string $tmpDirectory
     * @param [type] $tokenType
     * @return void
     */
    public function importFromFile(array $options, string $key, string $tmpDirectory, $tokenType, $importedBy = [])
    {
        $data = $this->loadDataFromDirectory($key, $tmpDirectory);
        return $this->import($data, $options, $tokenType, $importedBy);
    }

    public function loadDataFromDirectory(string $key, string $tmpDirectory)
    {
        $folderPath = $tmpDirectory . $key . '/';
        $folders_items = [];
        if (file_exists($folderPath)) {
            $folders_items = scandir($folderPath);
        }
        $data = [];
        foreach ($folders_items as $item) {
            $fixtureJsonPath = $folderPath . $item;
            if (is_file($fixtureJsonPath) && str_ends_with($item, '.json')) {
                $fixtureData = file_get_contents($fixtureJsonPath);
                $jsonData = json_decode($fixtureData, true);
                $fixtureFileName = basename($item, '.json');
                $data[$fixtureFileName] = $jsonData;
            }
        }
        return $data;
    }

    public function generateExportOptions(array $options, $tokenType = 'JWT')
    {
        return [];
    }

    public function generateInfoContent(array $options)
    {
        return [];
    }
}
